#!/bin/sh
#
# $Id: aircheck.sh,v 1.8 2013/05/28 19:49:11 cvsremote Exp $
#
# Usage: aircheck.sh [-l minutes] <station> <program>
#

##
## default recording (ripping) time: 2 hours
##
time=7200

##
## list of radio station URLs
##
stationList=$HOME/scripts/radio-urls.sh

##
## explicit path (optional)
##
prog=$HOME/bin/streamripper



usage () {
  echo "Usage: aircheck.sh [-l minutes] [-d ripping-dir] <station> <name>" 1>&2
  echo "Usage: aircheck.sh --list-stations" 1>&2
  exit 1
}
listRadioStations () {
  sed 's/^\(url_\)\(.*\)\(=.*\)$/\2/' $stationList
  exit 1
}
cleanup () {
  chmod 644 ${baseName}*.mp3
  for _file in ${baseName}*.cue
  do
    rm -f "$_file"
  done
  for _file in ${baseName}*.mp3
  do
    if [ -f $dir/"$_file" ]; then
      echo "$dir/$_file: already exists" 1>&2
      echo -n "Current dir: " 1>&2
      pwd 1>&2
    else
      mv "$_file" $dir
      echo "$_file is stored in $dir." 1>&2
    fi
  done
}
errExit () {
  cleanup
  exit 1
}

#
# Usage: changeDir <dir>
#
# Changes directory to <dir>.
# Directories are created if necessary.
#
changeDir () {
  _curDir=`pwd`

  if [ "`echo $1 | cut -c1`" = "/" ]; then
    cd /
  fi
  for _dir in `echo $1 | sed 's@/@ @g'`
  do
    if [ ! -d  $_dir ]; then
      if ! mkdir $_dir ; then
        cd $_curDir
        return 1
      fi
    fi
    cd $_dir
  done

  return 0
}

##
## default directories (1)
##
dir=$HOME/docs/audio/ripped
ripDir=$dir/.ripper

##
## traps
##
trap 'errExit' 2

##
## main
##
while [ $# -gt 0 ]
do
  case $1 in
  -h)   usage
        ;;
  --l*) listRadioStations
        ;;
  -l)   shift
        time=`expr 60 \* $1`
        ;;
  -d)   shift
        ripDir="$1"
        ;;
  *)    break
        ;;
  esac
  shift
done

if [ $# -lt 2 ]; then
  usage
fi

##
## load radio station list
##
#. $HOME/scripts/radio-urls.sh
. $stationList

station=`echo $1 | sed 's/-/_/g'`
eval url=\$url_$station
if [ -z "$url" ]; then
  echo "Error: $1: no such station" 1>&2
  exit 1
fi
title=$2

##
## default directories (2)
##
baseName=$title-`/bin/date '+%Y-%m%d'`
mp3File=$baseName.mp3
cueFile=$baseName.cue

if [ -z "$prog" ]; then
  if ! /usr/bin/streamripper >& /dev/null ; then
    echo "No streamripper in /usr/bin" 1>&2
    if ! /usr/local/bin/streamripper >& /dev/null ; then
      echo "No streamripper in /usr/localbin" 1>&2
      exit 1
    fi
  fi
fi


##
## Run streamripper.
## mp3 file is stored in $dir
##
if ! changeDir $ripDir ; then
  exit 1
fi

$prog $url -a $baseName -l $time
cleanup
